@@ -65,7 +65,8 @@ slurm_load_assoc_mgr_info(assoc_mgr_info_request_msg_t *req,
 	msg_request.msg_type = REQUEST_ASSOC_MGR_INFO;
 	msg_request.data = req;
 
-	cc = slurm_send_recv_controller_msg(&msg_request, &msg_reply);
+	cc = slurm_send_recv_controller_msg(&msg_request, &msg_reply,
+					    working_cluster_rec);
 	if (cc < 0)
 		return SLURM_ERROR;
 
