@@ -51,8 +51,8 @@
 #define SLURM_PROTOCOL_NO_SEND_RECV_FLAGS 0
 
 /* for listen API */
-#ifndef SLURM_PROTOCOL_DEFAULT_LISTEN_BACKLOG
-#define SLURM_PROTOCOL_DEFAULT_LISTEN_BACKLOG 4096
+#ifndef SLURM_DEFAULT_LISTEN_BACKLOG
+#define SLURM_DEFAULT_LISTEN_BACKLOG 4096
 #endif
 
 /* used in interface methods */
