@@ -278,8 +278,11 @@ static int _update_unused_wall(local_resv_usage_t *r_usage, List job_tres,
 	r_usage->unused_wall -=	(double)job_seconds * tres_ratio;
 
 	if (r_usage->unused_wall < 0) {
-		/* I'm not sure if I should error or silently ignore. */
-		debug3("WARNING: Unused wall is less than zero; this should never happen. Setting it to zero for resv id = %d, start = %ld.",
+		/*
+		 * With a Flex reservation you can easily have more time than is
+		 * possible.  Just print this debug3 warning if it happens.
+		 */
+		debug3("WARNING: Unused wall is less than zero; this should never happen outside a Flex reservation. Setting it to zero for resv id = %d, start = %ld.",
 		       r_usage->id, r_usage->orig_start);
 		r_usage->unused_wall = 0;
 	}
