@@ -46,6 +46,10 @@
 #include "src/common/xmalloc.h"
 #include "src/common/slurm_acct_gather_profile.h"
 
+// FIXME: We need to make it so we can use deprecated symbols.
+#undef H5_NO_DEPRECATED_SYMBOLS
+#define H5Oget_info_vers 1
+
 #include "hdf5_api.h"
 
 extern void profile_fini(void)
