@@ -63,6 +63,7 @@
 #include "src/common/macros.h"
 #include "src/common/pack.h"
 #include "src/common/parse_config.h"
+#include "src/common/run_command.h"
 #include "src/common/slurm_accounting_storage.h"
 #include "src/common/slurm_protocol_api.h"
 #include "src/common/timers.h"
@@ -80,10 +81,6 @@
 /* Maximum poll wait time for child processes, in milliseconds */
 #define MAX_POLL_WAIT 500
 
-static int bb_plugin_shutdown = 0;
-static int child_proc_count = 0;
-static pthread_mutex_t proc_count_mutex = PTHREAD_MUTEX_INITIALIZER;
-
 static void	_bb_job_del2(bb_job_t *bb_job);
 static uid_t *	_parse_users(char *buf);
 static char *	_print_users(uid_t *buf);
@@ -580,7 +577,7 @@ extern void bb_load_config(bb_state_t *state_ptr, char *plugin_type)
 static void _pack_alloc(struct bb_alloc *bb_alloc, Buf buffer,
 			uint16_t protocol_version)
 {
-	if (protocol_version >= SLURM_16_05_PROTOCOL_VERSION) {
+	if (protocol_version >= SLURM_MIN_PROTOCOL_VERSION) {
 		packstr(bb_alloc->account,      buffer);
 		pack32(bb_alloc->array_job_id,  buffer);
 		pack32(bb_alloc->array_task_id, buffer);
@@ -593,19 +590,6 @@ static void _pack_alloc(struct bb_alloc *bb_alloc, Buf buffer,
 		pack64(bb_alloc->size,          buffer);
 		pack16(bb_alloc->state,         buffer);
 		pack32(bb_alloc->user_id,       buffer);
-	} else {
-		packstr(bb_alloc->account,      buffer);
-		pack32(bb_alloc->array_job_id,  buffer);
-		pack32(bb_alloc->array_task_id, buffer);
-		pack_time(bb_alloc->create_time, buffer);
-		pack32((uint32_t)0, buffer);
-		pack32(bb_alloc->job_id,        buffer);
-		packstr(bb_alloc->name,         buffer);
-		packstr(bb_alloc->partition,    buffer);
-		packstr(bb_alloc->qos,          buffer);
-		pack64(bb_alloc->size,          buffer);
-		pack16(bb_alloc->state,         buffer);
-		pack32(bb_alloc->user_id,       buffer);
 	}
 }
 
@@ -678,7 +662,7 @@ extern void bb_pack_state(bb_state_t *state_ptr, Buf buffer,
 		pack64(state_ptr->unfree_space,      buffer);
 		pack64(state_ptr->used_space,        buffer);
 		pack32(config_ptr->validate_timeout, buffer);
-	} else if (protocol_version >= SLURM_16_05_PROTOCOL_VERSION) {
+	} else if (protocol_version >= SLURM_MIN_PROTOCOL_VERSION) {
 		packstr(config_ptr->allow_users_str, buffer);
 		packstr(config_ptr->create_buffer,   buffer);
 		packstr(config_ptr->default_pool,    buffer);
@@ -704,29 +688,6 @@ extern void bb_pack_state(bb_state_t *state_ptr, Buf buffer,
 		pack64(state_ptr->total_space,       buffer);
 		pack64(state_ptr->used_space,        buffer);
 		pack32(config_ptr->validate_timeout, buffer);
-	} else {
-		packstr(config_ptr->allow_users_str, buffer);
-		packstr(config_ptr->create_buffer,   buffer);
-		packstr(config_ptr->default_pool,    buffer);
-		packstr(config_ptr->deny_users_str,  buffer);
-		packstr(config_ptr->destroy_buffer,  buffer);
-		pack32(config_ptr->flags,            buffer);
-		packstr(config_ptr->get_sys_state,   buffer);
-		pack64(config_ptr->granularity,      buffer);
-		pack32(config_ptr->pool_cnt,         buffer);
-		for (i = 0; i < config_ptr->pool_cnt; i++) {
-			packstr(config_ptr->pool_ptr[i].name, buffer);
-			pack64(config_ptr->pool_ptr[i].total_space, buffer);
-			pack64(config_ptr->pool_ptr[i].used_space, buffer);
-		}
-		packstr(config_ptr->start_stage_in,  buffer);
-		packstr(config_ptr->start_stage_out, buffer);
-		packstr(config_ptr->stop_stage_in,   buffer);
-		packstr(config_ptr->stop_stage_out,  buffer);
-		pack32(config_ptr->stage_in_timeout, buffer);
-		pack32(config_ptr->stage_out_timeout,buffer);
-		pack64(state_ptr->total_space,       buffer);
-		pack64(state_ptr->used_space,        buffer);
 	}
 }
 
@@ -1127,186 +1088,6 @@ extern bool bb_free_alloc_rec(bb_state_t *state_ptr, bb_alloc_t *bb_alloc)
 	return false;
 }
 
-/*
- * Return time in msec since "start time"
- */
-static int _tot_wait (struct timeval *start_time)
-{
-	struct timeval end_time;
-	int msec_delay;
-
-	gettimeofday(&end_time, NULL);
-	msec_delay =   (end_time.tv_sec  - start_time->tv_sec ) * 1000;
-	msec_delay += ((end_time.tv_usec - start_time->tv_usec + 500) / 1000);
-	return msec_delay;
-}
-
-/* Terminate any child processes */
-extern void bb_shutdown(void)
-{
-	bb_plugin_shutdown = 1;
-}
-
-/* Return count of child processes */
-extern int bb_proc_count(void)
-{
-	int cnt;
-
-	slurm_mutex_lock(&proc_count_mutex);
-	cnt = child_proc_count;
-	slurm_mutex_unlock(&proc_count_mutex);
-
-	return cnt;
-}
-
-/* Execute a script, wait for termination and return its stdout.
- * script_type IN - Type of program being run (e.g. "StartStageIn")
- * script_path IN - Fully qualified pathname of the program to execute
- * script_args IN - Arguments to the script
- * max_wait IN - Maximum time to wait in milliseconds,
- *		 -1 for no limit (asynchronous)
- * status OUT - Job exit code
- * Return stdout+stderr of spawned program, value must be xfreed. */
-extern char *bb_run_script(char *script_type, char *script_path,
-			   char **script_argv, int max_wait, int *status)
-{
-	int i, new_wait, resp_size = 0, resp_offset = 0;
-	pid_t cpid;
-	char *resp = NULL;
-	int pfd[2] = { -1, -1 };
-
-	if ((script_path == NULL) || (script_path[0] == '\0')) {
-		error("%s: no script specified", __func__);
-		*status = 127;
-		resp = xstrdup("Slurm burst buffer configuration error");
-		return resp;
-	}
-	if (script_path[0] != '/') {
-		error("%s: %s is not fully qualified pathname (%s)",
-		      __func__, script_type, script_path);
-		*status = 127;
-		resp = xstrdup("Slurm burst buffer configuration error");
-		return resp;
-	}
-	if (access(script_path, R_OK | X_OK) < 0) {
-		error("%s: %s can not be executed (%s) %m",
-		      __func__, script_type, script_path);
-		*status = 127;
-		resp = xstrdup("Slurm burst buffer configuration error");
-		return resp;
-	}
-	if (max_wait != -1) {
-		if (pipe(pfd) != 0) {
-			error("%s: pipe(): %m", __func__);
-			*status = 127;
-			resp = xstrdup("System error");
-			return resp;
-		}
-	}
-	slurm_mutex_lock(&proc_count_mutex);
-	child_proc_count++;
-	slurm_mutex_unlock(&proc_count_mutex);
-	if ((cpid = fork()) == 0) {
-		int cc;
-
-		cc = sysconf(_SC_OPEN_MAX);
-		if (max_wait != -1) {
-			dup2(pfd[1], STDERR_FILENO);
-			dup2(pfd[1], STDOUT_FILENO);
-			for (i = 0; i < cc; i++) {
-				if ((i != STDERR_FILENO) &&
-				    (i != STDOUT_FILENO))
-					close(i);
-			}
-		} else {
-			for (i = 0; i < cc; i++)
-				close(i);
-			if ((cpid = fork()) < 0)
-				exit(127);
-			else if (cpid > 0)
-				exit(0);
-		}
-		setpgid(0, 0);
-		execv(script_path, script_argv);
-		error("%s: execv(%s): %m", __func__, script_path);
-		exit(127);
-	} else if (cpid < 0) {
-		if (max_wait != -1) {
-			close(pfd[0]);
-			close(pfd[1]);
-		}
-		error("%s: fork(): %m", __func__);
-		slurm_mutex_lock(&proc_count_mutex);
-		child_proc_count--;
-		slurm_mutex_unlock(&proc_count_mutex);
-	} else if (max_wait != -1) {
-		struct pollfd fds;
-		struct timeval tstart;
-		resp_size = 1024;
-		resp = xmalloc(resp_size);
-		close(pfd[1]);
-		gettimeofday(&tstart, NULL);
-		while (1) {
-			if (bb_plugin_shutdown) {
-				error("%s: killing %s operation on shutdown",
-				      __func__, script_type);
-				break;
-			}
-			fds.fd = pfd[0];
-			fds.events = POLLIN | POLLHUP | POLLRDHUP;
-			fds.revents = 0;
-			if (max_wait <= 0) {
-				new_wait = MAX_POLL_WAIT;
-			} else {
-				new_wait = max_wait - _tot_wait(&tstart);
-				if (new_wait <= 0) {
-					error("%s: %s poll timeout @ %d msec",
-					      __func__, script_type, max_wait);
-					break;
-				}
-				new_wait = MIN(new_wait, MAX_POLL_WAIT);
-			}
-			i = poll(&fds, 1, new_wait);
-			if (i == 0) {
-				continue;
-			} else if (i < 0) {
-				error("%s: %s poll:%m", __func__, script_type);
-				break;
-			}
-			if ((fds.revents & POLLIN) == 0)
-				break;
-			i = read(pfd[0], resp + resp_offset,
-				 resp_size - resp_offset);
-			if (i == 0) {
-				break;
-			} else if (i < 0) {
-				if (errno == EAGAIN)
-					continue;
-				error("%s: read(%s): %m", __func__,
-				      script_path);
-				break;
-			} else {
-				resp_offset += i;
-				if (resp_offset + 1024 >= resp_size) {
-					resp_size *= 2;
-					resp = xrealloc(resp, resp_size);
-				}
-			}
-		}
-		killpg(cpid, SIGTERM);
-		usleep(10000);
-		killpg(cpid, SIGKILL);
-		waitpid(cpid, status, 0);
-		close(pfd[0]);
-		slurm_mutex_lock(&proc_count_mutex);
-		child_proc_count--;
-		slurm_mutex_unlock(&proc_count_mutex);
-	} else {
-		waitpid(cpid, status, 0);
-	}
-	return resp;
-}
-
 /* Allocate a bb_job_t record, hashed by job_id, delete with bb_job_del() */
 extern bb_job_t *bb_job_alloc(bb_state_t *state_ptr, uint32_t job_id)
 {
@@ -1545,7 +1326,7 @@ extern int bb_post_persist_create(struct job_record *job_ptr,
 
 	memset(&resv, 0, sizeof(slurmdb_reservation_rec_t));
 	resv.assocs = bb_alloc->assocs;
-	resv.cluster = slurmctld_cluster_name;
+	resv.cluster = slurmctld_conf.cluster_name;
 	resv.name = bb_alloc->name;
 	resv.id = bb_alloc->id;
 	resv.time_start = bb_alloc->create_time;
@@ -1559,7 +1340,7 @@ extern int bb_post_persist_create(struct job_record *job_ptr,
 		while (assoc_ptr) {
 			assoc_ptr->usage->grp_used_tres[state_ptr->tres_pos] +=
 				size_mb;
-			debug2("%s: after adding persistant bb %s(%u), "
+			debug2("%s: after adding persistent bb %s(%u), "
 			       "assoc %u(%s/%s/%s) grp_used_tres(%s) "
 			       "is %"PRIu64,
 			       __func__, bb_alloc->name, bb_alloc->id,
@@ -1572,7 +1353,7 @@ extern int bb_post_persist_create(struct job_record *job_ptr,
 			/* FIXME: should grp_used_tres_run_secs be
 			 * done some how? Same for QOS below.
 			 */
-			/* debug2("%s: after adding persistant bb %s(%u), " */
+			/* debug2("%s: after adding persistent bb %s(%u), " */
 			/*        "assoc %u(%s/%s/%s) grp_used_tres_run_secs(%s) " */
 			/*        "is %"PRIu64, */
 			/*        __func__, bb_alloc->name, bb_alloc->id, */
@@ -1613,7 +1394,7 @@ extern int bb_post_persist_delete(bb_alloc_t *bb_alloc, bb_state_t *state_ptr)
 
 	memset(&resv, 0, sizeof(slurmdb_reservation_rec_t));
 	resv.assocs = bb_alloc->assocs;
-	resv.cluster = slurmctld_cluster_name;
+	resv.cluster = slurmctld_conf.cluster_name;
 	resv.name = bb_alloc->name;
 	resv.id = bb_alloc->id;
 	resv.time_end = time(NULL);
@@ -1631,7 +1412,7 @@ extern int bb_post_persist_delete(bb_alloc_t *bb_alloc, bb_state_t *state_ptr)
 			    >= size_mb) {
 				assoc_ptr->usage->grp_used_tres[
 					state_ptr->tres_pos] -= size_mb;
-				debug2("%s: after removing persistant "
+				debug2("%s: after removing persistent "
 				       "bb %s(%u), assoc %u(%s/%s/%s) "
 				       "grp_used_tres(%s) is %"PRIu64,
 				       __func__, bb_alloc->name, bb_alloc->id,
@@ -1642,7 +1423,7 @@ extern int bb_post_persist_delete(bb_alloc_t *bb_alloc, bb_state_t *state_ptr)
 				       assoc_ptr->usage->
 				       grp_used_tres[state_ptr->tres_pos]);
 			} else {
-				error("%s: underflow removing persistant "
+				error("%s: underflow removing persistent "
 				      "bb %s(%u), assoc %u(%s/%s/%s) "
 				      "grp_used_tres(%s) had %"PRIu64
 				      " but we are trying to remove %"PRIu64,
@@ -1660,7 +1441,7 @@ extern int bb_post_persist_delete(bb_alloc_t *bb_alloc, bb_state_t *state_ptr)
 
 			/* FIXME: should grp_used_tres_run_secs be
 			 * done some how? Same for QOS below. */
-			/* debug2("%s: after removing persistant bb %s(%u), " */
+			/* debug2("%s: after removing persistent bb %s(%u), " */
 			/*        "assoc %u(%s/%s/%s) grp_used_tres_run_secs(%s) " */
 			/*        "is %"PRIu64, */
 			/*        __func__, bb_alloc->name, bb_alloc->id, */
