@@ -250,7 +250,9 @@ static void *_agent_thread(void *unused)
 		pmixp_dconn_regio(_io_handle);
 	}
 
-	pthread_cond_signal(&agent_running_cond);
+	slurm_mutex_lock(&agent_mutex);
+	slurm_cond_signal(&agent_running_cond);
+	slurm_mutex_unlock(&agent_mutex);
 
 	eio_handle_mainloop(_io_handle);
 
