@@ -2563,37 +2563,15 @@ unpack_error:
 extern char *select_p_select_jobinfo_sprint(select_jobinfo_t *jobinfo,
 					    char *buf, size_t size, int mode)
 {
-
-	if (buf == NULL) {
-		error("select/cray jobinfo_sprint: buf is null");
-		return NULL;
-	}
-
-	if ((mode != SELECT_PRINT_DATA)
-	    && jobinfo && (jobinfo->magic != JOBINFO_MAGIC)) {
-		error("select/cray jobinfo_sprint: jobinfo magic bad");
-		return NULL;
-	}
-
-	if (jobinfo == NULL) {
-		if (mode != SELECT_PRINT_HEAD) {
-			error("select/cray jobinfo_sprint: jobinfo bad");
-			return NULL;
-		}
-		/* FIXME: in the future print out the header here (if needed) */
-		/* snprintf(buf, size, "%s", header); */
-
+	/*
+	 * Skip call to other_select_jobinfo_sprint, all of the other select
+	 * plugins we can layer on top of do this same thing anyways:
+	 */
+	if (buf && size) {
+		buf[0] = '\0';
 		return buf;
-	}
-
-	switch (mode) {
-	default:
-		other_select_jobinfo_sprint(jobinfo->other_jobinfo, buf,
-					    size, mode);
-		break;
-	}
-
-	return buf;
+	} else
+		return NULL;
 }
 
 extern char *select_p_select_jobinfo_xstrdup(select_jobinfo_t *jobinfo,
