@@ -109,6 +109,10 @@ static inline int hwloc_bitmap_isequal(
 
 # endif
 
+#if HWLOC_API_VERSION >= 0x00020000
+static hwloc_bitmap_t global_allowed_cpuset;
+#endif
+
 hwloc_obj_type_t obj_types[3] = {HWLOC_OBJ_SOCKET, HWLOC_OBJ_CORE,
 			         HWLOC_OBJ_PU};
 
@@ -464,15 +468,22 @@ static void _add_hwloc_cpuset(
 	hwloc_obj_t obj, uint32_t taskid,  int bind_verbose,
 	hwloc_bitmap_t cpuset)
 {
+#if HWLOC_API_VERSION >= 0x00020000
+	hwloc_bitmap_t allowed_cpuset;
+#endif
 	struct hwloc_obj *pobj;
 
-	/* if requested binding overlaps the granularity */
-	/* use the ancestor cpuset instead of the object one */
+	/*
+	 * if requested binding overlaps the granularity
+	 * use the ancestor cpuset instead of the object one
+	 */
 	if (hwloc_compare_types(hwtype, req_hwtype) > 0) {
 
-		/* Get the parent object of req_hwtype or the */
-		/* one just above if not found (meaning of >0)*/
-		/* (useful for ldoms binding with !NUMA nodes)*/
+		/*
+		 * Get the parent object of req_hwtype or the
+		 * one just above if not found (meaning of >0
+		 * (useful for ldoms binding with !NUMA nodes)
+		 */
 		pobj = obj->parent;
 		while (pobj != NULL &&
 			hwloc_compare_types(pobj->type, req_hwtype) > 0)
@@ -483,17 +494,41 @@ static void _add_hwloc_cpuset(
 				info("task/cgroup: task[%u] higher level %s "
 				     "found", taskid,
 				     hwloc_obj_type_string(pobj->type));
+#if HWLOC_API_VERSION >= 0x00020000
+			allowed_cpuset = hwloc_bitmap_alloc();
+			hwloc_bitmap_and(allowed_cpuset, global_allowed_cpuset,
+					 pobj->cpuset);
+			hwloc_bitmap_or(cpuset, cpuset, allowed_cpuset);
+			hwloc_bitmap_free(allowed_cpuset);
+#else
 			hwloc_bitmap_or(cpuset, cpuset, pobj->allowed_cpuset);
+#endif
 		} else {
 			/* should not be executed */
 			if (bind_verbose)
 				info("task/cgroup: task[%u] no higher level "
 				     "found", taskid);
+#if HWLOC_API_VERSION >= 0x00020000
+			allowed_cpuset = hwloc_bitmap_alloc();
+			hwloc_bitmap_and(allowed_cpuset, global_allowed_cpuset,
+					 obj->cpuset);
+			hwloc_bitmap_or(cpuset, cpuset, allowed_cpuset);
+			hwloc_bitmap_free(allowed_cpuset);
+#else
 			hwloc_bitmap_or(cpuset, cpuset, obj->allowed_cpuset);
+#endif
 		}
 
 	} else {
+#if HWLOC_API_VERSION >= 0x00020000
+		allowed_cpuset = hwloc_bitmap_alloc();
+		hwloc_bitmap_and(allowed_cpuset, global_allowed_cpuset,
+				 obj->cpuset);
+		hwloc_bitmap_or(cpuset, cpuset, allowed_cpuset);
+		hwloc_bitmap_free(allowed_cpuset);
+#else
 		hwloc_bitmap_or(cpuset, cpuset, obj->allowed_cpuset);
+#endif
 	}
 }
 
@@ -502,6 +537,9 @@ static int _task_cgroup_cpuset_dist_cyclic(
 	hwloc_obj_type_t req_hwtype, stepd_step_rec_t *job, int bind_verbose,
 	hwloc_bitmap_t cpuset)
 {
+#if HWLOC_API_VERSION >= 0x00020000
+	hwloc_bitmap_t allowed_cpuset;
+#endif
 	hwloc_obj_t obj;
 	uint32_t  s_ix;		/* socket index */
 	uint32_t *c_ixc;	/* core index by socket (current taskid) */
@@ -603,22 +641,38 @@ static int _task_cgroup_cpuset_dist_cyclic(
 		}
 	}
 
-	/* skip objs for lower taskids, then add them to the
-	   current task cpuset. To prevent infinite loop, check
-	   that we do not loop more than npdist times around the available
-	   sockets, which is the worst scenario we should afford here. */
+	/*
+	 * skip objs for lower taskids, then add them to the
+	 * current task cpuset. To prevent infinite loop, check
+	 * that we do not loop more than npdist times around the available
+	 * sockets, which is the worst scenario we should afford here.
+	 */
 	i = j = s_ix = sock_loop = 0;
 	while (i < ntskip + 1 && (sock_loop/tpc) < npdist + 1) {
-		/* fill one or multiple sockets using block mode, unless
-		   otherwise stated in the job->task_dist field */
+		/*
+		 * fill one or multiple sockets using block mode, unless
+		 * otherwise stated in the job->task_dist field
+		 */
 		while ((s_ix < nsockets) && (j < npdist)) {
 			obj = hwloc_get_obj_below_by_type(
 				topology, HWLOC_OBJ_SOCKET, s_ix,
 				hwtype, c_ixc[s_ix]);
+#if HWLOC_API_VERSION >= 0x00020000
+			if (obj) {
+				allowed_cpuset = hwloc_bitmap_alloc();
+				hwloc_bitmap_and(allowed_cpuset,
+						 global_allowed_cpuset,
+						 obj->cpuset);
+			}
+#endif
 			if ((obj == NULL) && (s_ix == 0) && (c_ixc[s_ix] == 0))
 				hwloc_success = false;	/* Complete failure */
 			if ((obj != NULL) &&
+#if HWLOC_API_VERSION >= 0x00020000
+			    (hwloc_bitmap_first(allowed_cpuset) != -1)) {
+#else
 			    (hwloc_bitmap_first(obj->allowed_cpuset) != -1)) {
+#endif
 				if (hwloc_compare_types(hwtype, HWLOC_OBJ_PU)
 									>= 0) {
 					/* granularity is thread */
@@ -628,8 +682,13 @@ static int _task_cgroup_cpuset_dist_cyclic(
 					obj = hwloc_get_obj_below_array_by_type(
 						topology, 3, obj_types, obj_idxs);
 					if ((obj != NULL) &&
+#if HWLOC_API_VERSION >= 0x00020000
+					    (hwloc_bitmap_first(
+					     allowed_cpuset) != -1)) {
+#else
 					    (hwloc_bitmap_first(
 					     obj->allowed_cpuset) != -1)) {
+#endif
 						t_ix[(s_ix*cps)+c_ixc[s_ix]]++;
 						j++;
 						if (i == ntskip)
@@ -666,6 +725,10 @@ static int _task_cgroup_cpuset_dist_cyclic(
 				}
 			} else
 				s_ix++;
+#if HWLOC_API_VERSION >= 0x00020000
+			if (obj)
+				hwloc_bitmap_free(allowed_cpuset);
+#endif
 		}
 		/* if it succeeds, switch to the next task, starting
 		 * with the next available socket, otherwise, loop back
@@ -871,13 +934,24 @@ static int _task_cgroup_cpuset_dist_block(
 /* The job has specialized cores, synchronize user mask with available cores */
 static void _validate_mask(uint32_t task_id, hwloc_obj_t obj, cpu_set_t *ts)
 {
+#if HWLOC_API_VERSION >= 0x00020000
+	hwloc_bitmap_t allowed_cpuset;
+#endif
 	int i, j, overlaps = 0;
 	bool superset = true;
 
+#if HWLOC_API_VERSION >= 0x00020000
+	allowed_cpuset = hwloc_bitmap_alloc();
+	hwloc_bitmap_and(allowed_cpuset, global_allowed_cpuset, obj->cpuset);
+#endif
 	for (i = 0; i < CPU_SETSIZE; i++) {
 		if (!CPU_ISSET(i, ts))
 			continue;
+#if HWLOC_API_VERSION >= 0x00020000
+		j = hwloc_bitmap_isset(allowed_cpuset, i);
+#else
 		j = hwloc_bitmap_isset(obj->allowed_cpuset, i);
+#endif
 		if (j > 0) {
 			overlaps++;
 		} else if (j == 0) {
@@ -887,10 +961,16 @@ static void _validate_mask(uint32_t task_id, hwloc_obj_t obj, cpu_set_t *ts)
 	}
 
 	if (overlaps == 0) {
-		/* The task's cpu map is completely invalid.
-		 * Give it all allowed CPUs */
+		/*
+		 * The task's cpu map is completely invalid.
+		 * Give it all allowed CPUs
+		 */
 		for (i = 0; i < CPU_SETSIZE; i++) {
+#if HWLOC_API_VERSION >= 0x00020000
+			if (hwloc_bitmap_isset(allowed_cpuset, i) > 0)
+#else
 			if (hwloc_bitmap_isset(obj->allowed_cpuset, i) > 0)
+#endif
 				CPU_SET(i, ts);
 		}
 	}
@@ -901,6 +981,9 @@ static void _validate_mask(uint32_t task_id, hwloc_obj_t obj, cpu_set_t *ts)
 		fprintf(stderr, "Requested cpu_bind option outside of job "
 			"step allocation for task[%u]\n", task_id);
 	}
+#if HWLOC_API_VERSION >= 0x00020000
+	hwloc_bitmap_free(allowed_cpuset);
+#endif
 }
 
 #endif
@@ -1276,13 +1359,17 @@ extern int task_cgroup_cpuset_set_task_affinity(stepd_step_rec_t *job)
 	uint32_t taskid = job->envtp->localid;
 	uint32_t jntasks = job->node_tasks;
 	uint32_t jnpus;
+	int spec_threads = 0;
 
 	/* Allocate and initialize hwloc objects */
 	hwloc_topology_init(&topology);
 	hwloc_topology_load(topology);
 	cpuset = hwloc_bitmap_alloc();
-
-	int spec_threads = 0;
+#if HWLOC_API_VERSION >= 0x00020000
+	global_allowed_cpuset = hwloc_bitmap_alloc();
+	(void) hwloc_bitmap_copy(global_allowed_cpuset,
+				 hwloc_topology_get_allowed_cpuset(topology));
+#endif
 
 	if (job->batch) {
 		jnpus = job->cpus;
@@ -1540,6 +1627,9 @@ extern int task_cgroup_cpuset_set_task_affinity(stepd_step_rec_t *job)
 	/* Destroy hwloc objects */
 	hwloc_bitmap_free(cpuset);
 	hwloc_topology_destroy(topology);
+#if HWLOC_API_VERSION >= 0x00020000
+	hwloc_bitmap_free(global_allowed_cpuset);
+#endif
 
 	return fstatus;
 #endif
