@@ -44,6 +44,7 @@
 
 #define XCGROUP_ERROR    1
 #define XCGROUP_SUCCESS  0
+#define MAX_MOVE_WAIT 5000
 
 // http://lists.debian.org/debian-boot/2012/04/msg00047.html
 #if defined(__FreeBSD__) || defined(__NetBSD__)
@@ -317,4 +318,11 @@ int xcgroup_get_uint64_param(xcgroup_t* cg, char* param, uint64_t* value);
  */
 int xcgroup_move_process(xcgroup_t *cg, pid_t pid);
 
+/*
+ * Wait for a pid to move out of a cgroup.
+ *
+ * Must call xcgroup_move_process before this function.
+ */
+int xcgroup_wait_pid_moved(xcgroup_t *cg, const char *cg_name);
+
 #endif
