@@ -69,6 +69,10 @@ extern slurmd_conf_t *conf;
 extern int stepd_cleanup(slurm_msg_t *msg, stepd_step_rec_t *job,
 			 slurm_addr_t *cli, slurm_addr_t *self,
 			 int rc, bool only_mem);
+extern int stepd_drain_node(char *reason);
+extern int stepd_send_pending_exit_msgs(stepd_step_rec_t *job);
+extern void stepd_send_step_complete_msgs(stepd_step_rec_t *job);
+extern void stepd_wait_for_children_slurmstepd(stepd_step_rec_t *job);
 
 extern void close_slurmd_conn(void);
 
